@@ -27,3 +27,7 @@ def _load_jupyter_server_extension(server_app):
         JupyterLab application instance
     """
     setup_handlers(server_app.web_app)
+
+
+# For backward compatibility
+load_jupyter_server_extension = _load_jupyter_server_extension
